@@ -45,6 +45,18 @@ def generate_lookback_contravariant(lookback_windows, contravariants):
             })
     return parameters
 
+def generate_slope_induced(lookback_windows, contravariants, slope_columns):
+    parameters = []
+    for lookback_window in lookback_windows:
+        for contravariant in contravariants:
+            for slope_column in slope_columns:
+                parameters.append({
+                    'lookback_window':lookback_window,
+                    'contravariant':contravariant,
+                    'slope_column' : slope_column
+                })
+    return parameters
+
 def generate_alpha_8(lookback_windows, contravariants, lags):
     parameters = []
     for lookback_window in lookback_windows:
